@@ -418,9 +418,8 @@ class Utils(object):
 		return variables
 
 	@classmethod
-	def upload_output(cls, aws_config, app_id, output_file):
+	def upload_output(cls, aws_config, app_id, scan_id, output_file):
 		print('Uploading output file...')
-		timestamp = cls.get_formated_timestamp()
 		file_name = ''
 		output_file_handle = None
 		cloc_file_handle = None
@@ -440,13 +439,13 @@ class Utils(object):
 			s3 = session.resource('s3', config=config)
 			file_name = ntpath.basename(output_file)
 			output_file_handle = open(output_file, 'rb')
-			s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + timestamp + '/' + file_name, Body=output_file_handle)
+			s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + scan_id + '/' + file_name, Body=output_file_handle)
 
 			# upload cloc file
 			try:
 				if cls.cloc_file is not None and os.path.exists(cls.cloc_file):
 					cloc_file_handle = open(cls.cloc_file, 'rb')
-					s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + timestamp + '/sken-cloc.json', Body=cloc_file_handle)
+					s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + scan_id + '/sken-cloc.json', Body=cloc_file_handle)
 			except Exception as ce:
 				pass
 		
@@ -464,7 +463,7 @@ class Utils(object):
 			except Exception as fe:
 				pass
 
-		return timestamp
+		return scan_id
 
 	@classmethod
 	def remove_duplicated_items_list(cls, list_object):
